@@ -43,7 +43,7 @@
 #define PROG_RMMOD		"/sbin/rmmod"
 #define PROG_CARDCTL		"/sbin/cardctl"
 #define PROG_UDEVINFO		"/usr/bin/udevinfo"
-#define PROG_UDEVADM		"/sbin/udevadm"
+#define PROG_UDEVADM		"/usr/bin/udevadm"
 
 #define KLOG_BOOT		"/var/log/boot.msg"
 #define ISAPNP_CONF		"/etc/isapnp.conf"
